#include "qnetworkreply.h"

QBuffer QNetworkReply::data;

QNetworkReply::QNetworkReply()
{
    data.open(QIODevice::ReadOnly);
}

QNetworkReply::~QNetworkReply()
{
    close();
}

QByteArray QNetworkReply::readAll()
{
    return data.data();
}

int QNetworkReply::error() const
{
    return 0;
}

void QNetworkReply::close()
{
    data.close();
}

void QNetworkReply::deleteLater()
{
}

QByteArray QNetworkReply::readLine(qint64 maxlen)
{
    return data.readLine(maxlen);
}


